==> how-to-cook-1.1.0.tgz: package/dishes/meat_dish/宫保鸡丁/宫保鸡丁.md <==
# 宫保鸡丁的做法

老派川菜的简单做法分享

## 必备原料和工具

- 手枪腿（或者鸡胸脯肉）
- 大葱
- 干辣椒（或者二荆条）
- 熟花生
- 生抽酱油
- 香醋
- 白糖
- 料酒
- 盐
- 鸡精
- 淀粉
- 植物油
- 芝麻油

### 可选原料

- 油泼辣子
- 莴笋
- 生花生
- 豆瓣酱

## 计算

注意，这道菜默认一人版本，两人也够吃，理论上多人只需简单加倍即可。

- 必须配料
  - 手枪腿（或者鸡胸脯肉） = 1 支（约 350g）
  - 大葱 = 1 根（约 180g）
  - 熟花生 = 150g
  - 姜片 = 10g
  - 干辣椒（或者二荆条） = 10g（若选择二荆条，则需要大约 4 支）
  - 生抽酱油 = 10g
  - 白糖 = 2g
  - 盐 = 2g
  - 植物油 = 20g
  - 淀粉 = 15g
  - 料酒 = 15g
- 进阶配料
  - 老抽酱油 = 5g
  - 花椒 = 5g
  - 香醋 = 5g
  - 鸡精 = 2g
  - 芝麻油 = 10g
  - 淀粉（用以勾芡） = 10g
  - 豆瓣酱 = 10g
- 可选配料
  - 莴笋 = 约 250g
  - 油泼辣子 = 5g

使用上述条件，计算出计划使用的原材料比例，依口味调整。

## 操作

### 简易版本

- 手枪腿用剪刀去骨，鸡肉面用刀背拍打一遍，切条后切至 1.5cm 见方肉丁；泡于清水 10min，捞出控干备用（若是鸡胸脯肉，则可以直接进行切丁以及之后的动作）
- 取大葱葱绿与姜片 5g 于碗中，倒入 50g 开水备用；葱白切 1.5cm 圆粒备用；取花生放入微波炉高火 5 分钟焙干备用
- 鸡丁中加入盐 2g，老抽酱油 5g，料酒 15g，淀粉 15g 搅拌均匀，至微微发干；缓慢加入部分葱姜水，搅拌鸡丁至粘手；保鲜膜密封，放入冰箱腌制 1 小时
- 干辣椒切段；起锅，大火烧热转小火；放入干辣椒焙干至微微发糊，捞起备用；花椒焙干至有香味，捞起备用
- 转大火，倒入 20g 植物油，7 成热（竹筷子起泡）下入鸡丁，煎至上面开始发白，用锅铲翻面，煎 30s 后翻炒均匀
- 下入葱粒翻炒，加入余下葱姜水不够 100g 再加一点清水（务必是热水）；盖上锅盖，转中小火焖 2min；
- 转大火，下入熟花生，干辣椒和花椒；加入鸡精 2g，香醋 5g，白糖 2g，翻炒均匀；
- 淀粉 10g 加 50g 清水调成水淀粉，加入锅中，翻炒均匀，收汁到自己想要的浓度
- 关火，淋入芝麻油 10g，即可出锅

### 稍加复杂但是更加令人垂涎欲滴的版本

相较于简单版本，这里更加推荐使用二荆条与生花生。并且加入了莴笋陪衬花生的香脆与鸡肉的松软

- 莴笋去皮切至 1cm 见方的小块，备用；
- 二荆条切成 1cm 长段；
- 手枪腿用剪刀去骨，鸡肉面用刀背拍打一遍，切条后切至 1.5cm 见方肉丁；泡于清水 10min，捞出控干备用（若是鸡胸脯肉，则可以直接进行切丁以及之后的动作）；
- 取大葱葱绿与姜片 5g 于碗中，倒入 50g 开水备用；葱白切 1.5cm 圆粒备用
- 鸡丁中加入盐 2g，老抽酱油 5g，料酒 15g，淀粉 15g 搅拌均匀，至微微发干；缓慢加入部分葱姜水，搅拌鸡丁至粘手；保鲜膜密封，放入冰箱腌制 1 小时
- 转中火，倒入 20g 植物油，放入生花生翻炒至其表面微微焦糊，捞起花生但是油留在锅内；
- 继续加热，7 成热（竹筷子起泡）下入鸡丁，放入豆瓣酱，翻炒大概 1min；
- 加入备好的莴笋丁，继续翻炒 1min；
- 下入葱粒翻炒，加入余下葱姜水不够 100g 再加一点清水（务必是热水）；加入二荆条段；盖上锅盖，转中小火焖 2min；
- 转大火，下入先前捞起来备用的花生，花椒；加入鸡精 2g，香醋 5g，白糖 2g，翻炒均匀；
- 淀粉 10g 加 50g 清水调成水淀粉，加入锅中，翻炒均匀，收汁到自己想要的浓度
- 关火，淋入芝麻油 10g 与油泼辣子 5g 再翻炒 10s，即可出锅

![宫保鸡丁](./宫保鸡丁.jpg)

## 附加内容

辣椒依据个人口味酌量添加，怕辣可去籽；

如果您遵循本指南的制作流程而发现有问题或可以改进的流程，请提出 Issue 或 Pull request 。

==> how-to-cook-1.2.0.tgz: package/dishes/meat_dish/宫保鸡丁/宫保鸡丁.md <==
# 宫保鸡丁的做法

老派川菜的简单做法分享

## 必备原料和工具

- 手枪腿（或者鸡胸脯肉）
- 大葱
- 干辣椒（或者二荆条）
- 熟花生
- 生抽酱油
- 香醋
- 白糖
- 料酒
- 盐
- 鸡精
- 淀粉
- 植物油
- 芝麻油

### 可选原料

- 油泼辣子
- 莴笋
- 生花生
- 豆瓣酱

## 计算

注意，这道菜默认一人版本，两人也够吃，理论上多人只需简单加倍即可。

- 必须配料
  - 手枪腿（或者鸡胸脯肉） = 1 支（约 350g）
  - 大葱 = 1 根（约 180g）
  - 熟花生 = 150g
  - 姜片 = 10g
  - 干辣椒（或者二荆条） = 10g（若选择二荆条，则需要大约 4 支）
  - 生抽酱油 = 10g
  - 白糖 = 2g
  - 盐 = 2g
  - 植物油 = 20g
  - 淀粉 = 15g
  - 料酒 = 15g
- 进阶配料
  - 老抽酱油 = 5g
  - 花椒 = 5g
  - 香醋 = 5g
  - 鸡精 = 2g
  - 芝麻油 = 10g
  - 淀粉（用以勾芡） = 10g
  - 豆瓣酱 = 10g
- 可选配料
  - 莴笋 = 约 250g
  - 油泼辣子 = 5g

使用上述条件，计算出计划使用的原材料比例，依口味调整。

## 操作

### 简易版本

- 手枪腿用剪刀去骨，鸡肉面用刀背拍打一遍，切条后切至 1.5cm 见方肉丁；泡于清水 10 分钟，捞出控干备用（若是鸡胸脯肉，则可以直接进行切丁以及之后的动作）
- 取大葱葱绿与姜片 5g 于碗中，倒入 50g 开水备用；葱白切 1.5cm 圆粒备用；取花生放入微波炉高火 5 分钟焙干备用
- 鸡丁中加入盐 2g，老抽酱油 5g，料酒 15g，淀粉 15g 搅拌均匀，至微微发干；缓慢加入部分葱姜水，搅拌鸡丁至粘手；保鲜膜密封，放入冰箱腌制 1 小时
- 干辣椒切段；起锅，大火烧热转小火；放入干辣椒焙干至微微发糊，捞起备用；花椒焙干至有香味，捞起备用
- 转大火，倒入 20g 植物油，7 成热（竹筷子起泡）下入鸡丁，煎至上面开始发白，用锅铲翻面，煎 30s 后翻炒均匀
- 下入葱粒翻炒，加入余下葱姜水不够 100g 再加一点清水（务必是热水）；盖上锅盖，转中小火焖 2 分钟；
- 转大火，下入熟花生，干辣椒和花椒；加入鸡精 2g，香醋 5g，白糖 2g，翻炒均匀；
- 淀粉 10g 加 50g 清水调成水淀粉，加入锅中，翻炒均匀，收汁到自己想要的浓度
- 关火，淋入芝麻油 10g，即可出锅

### 稍加复杂但是更加令人垂涎欲滴的版本

相较于简单版本，这里更加推荐使用二荆条与生花生。并且加入了莴笋陪衬花生的香脆与鸡肉的松软

- 莴笋去皮切至 1cm 见方的小块，备用；
- 二荆条切成 1cm 长段；
- 手枪腿用剪刀去骨，鸡肉面用刀背拍打一遍，切条后切至 1.5cm 见方肉丁；泡于清水 10 分钟，捞出控干备用（若是鸡胸脯肉，则可以直接进行切丁以及之后的动作）；
- 取大葱葱绿与姜片 5g 于碗中，倒入 50g 开水备用；葱白切 1.5cm 圆粒备用
- 鸡丁中加入盐 2g，老抽酱油 5g，料酒 15g，淀粉 15g 搅拌均匀，至微微发干；缓慢加入部分葱姜水，搅拌鸡丁至粘手；保鲜膜密封，放入冰箱腌制 1 小时
- 转中火，倒入 20g 植物油，放入生花生翻炒至其表面微微焦糊，捞起花生但是油留在锅内；
- 继续加热，7 成热（竹筷子起泡）下入鸡丁，放入豆瓣酱，翻炒大概 1 分钟；
- 加入备好的莴笋丁，继续翻炒 1 分钟；
- 下入葱粒翻炒，加入余下葱姜水不够 100g 再加一点清水（务必是热水）；加入二荆条段；盖上锅盖，转中小火焖 2 分钟；
- 转大火，下入先前捞起来备用的花生，花椒；加入鸡精 2g，香醋 5g，白糖 2g，翻炒均匀；
- 淀粉 10g 加 50g 清水调成水淀粉，加入锅中，翻炒均匀，收汁到自己想要的浓度
- 关火，淋入芝麻油 10g 与油泼辣子 5g 再翻炒 10s，即可出锅

![宫保鸡丁](./宫保鸡丁.jpg)

## 附加内容

辣椒依据个人口味酌量添加，怕辣可去籽；

如果您遵循本指南的制作流程而发现有问题或可以改进的流程，请提出 Issue 或 Pull request 。
